
Title
=====

SubTitle
--------

**content**

サブタイトル
------------

`A link to GitHub <http://github.com/>`_

This is :math:`E = mc^2` inline math.

This first math :math:`x^2` in this line will render. This one :math:`z^3` should as well.

Also within parentheses (:math:`x^2`) and (:math:`z^3`).

.. code-block:: mermaid

   graph TD;
       A-->B;
       A-->C;
       B-->D;
       C-->D;
